==> haskell-os-string-2.0.8-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 os-string
version:              2.0.8
visibility:           public
id:                   os-string-2.0.8-6aVeiz5tOYHIVoxunTaaLG
key:                  os-string-2.0.8-6aVeiz5tOYHIVoxunTaaLG
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  f559e1226135e7ef51053ebd7d4635f7
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Exception
    System.OsString.Internal.Types System.OsString.Posix
    System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.8-6aVeiz5tOYHIVoxunTaaLG
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 exceptions-0.10.7
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-os-string-2.0.8-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 os-string
version:              2.0.8
visibility:           public
id:                   os-string-2.0.8-AA1bdU0kXW8K5RZiFLM6SM
key:                  os-string-2.0.8-AA1bdU0kXW8K5RZiFLM6SM
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  3e20a00af0a8efebea6422282cc17c31
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Exception
    System.OsString.Internal.Types System.OsString.Posix
    System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.8-AA1bdU0kXW8K5RZiFLM6SM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 exceptions-0.10.7
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
